@@ -19,8 +19,7 @@ class FiggyAction:
             print(f"{c.fg_yl}Executing action: {child.args}{c.rs}")
             self._child = child
             self._child.logfile = sys.stdout
-            self._child.delayafterread = .01
-            self._child.delaybeforesend = .25
+            self._child.delaybeforesend = .5
 
     def expect_multiple(self, regexes: List[str]):
         print(f'Expecting: {regexes}')
@@ -36,3 +35,8 @@ class FiggyAction:
 
     def wait(self):
         self._child.wait()
+
+    def alert(self, msg: str):
+        print(f"{self.c.fg_yl}-----------------------------------------{self.c.rs}")
+        print(f"{self.c.fg_rd} ALERT: {msg}{self.c.rs}")
+        print(f"{self.c.fg_yl}-----------------------------------------{self.c.rs}")
\ No newline at end of file
