@@ -1,14 +1,15 @@
 import sys
+import time
 
 import pexpect
+from figcli.test.cli.test_utils import TestUtils
+
+from figcli.test.cli.actions.delete import DeleteAction
+from figcli.test.cli.actions.get import GetAction
+from figcli.test.cli.actions.put import PutAction
 from figcli.test.cli.config import *
 from figcli.test.cli.figgy import FiggyTest
-from figcli.test.cli.dev.put import DevPut
-from figcli.test.cli.dev.get import DevGet
-from figcli.test.cli.dev.delete import DevDelete
-from figcli.config import *
 from figcli.utils.utils import *
-import time
 
 KEY_UP = 'k'
 KEY_DOWN = 'j'
@@ -24,24 +25,24 @@ class DevBrowse(FiggyTest):
     def run(self):
         self.step("Prepping browse")
         self._setup()
-        self.step("Sleeping for 25 to ensure the cache gets populated with the new /shared value")
-        time.sleep(25)
+        self.step("Sleeping for 45 to ensure the cache gets populated with the new /shared value")
+        time.sleep(45)
         self.step(f"Testing browse for {param_1}")
         self.browse()
         self.step("Cleaning up")
         self._cleanup()
 
     def _cleanup(self):
-        delete = DevDelete(extra_args=self.extra_args)
+        delete = DeleteAction(extra_args=self.extra_args)
         delete.delete(KEY_PATH, delete_another=False)
 
     def _setup(self):
-        put = DevPut(extra_args=self.extra_args)
+        put = PutAction(extra_args=self.extra_args)
         put.add(KEY_PATH, DELETE_ME_VALUE, param_1_desc, add_more=False, delete_first=False)
 
     def _validate_delete(self, key, value):
         print(f"Validating successfully deletion of {key}")
-        get = DevGet(extra_args=self.extra_args)
+        get = GetAction(extra_args=self.extra_args)
         get.get(key, value, get_more=False, expect_missing=True)
         print("Delete success validated.")
 
@@ -49,14 +50,13 @@ class DevBrowse(FiggyTest):
     def browse(self):
         print(f"Getting {KEY_PATH} through browse...")
         # Get Value
-        child = pexpect.spawn(f'{CLI_NAME} config {Utils.get_first(browse)} --env {DEFAULT_ENV} '
-                              f'--skip-upgrade {self.extra_args}',
-                              timeout=20, encoding='utf-8')
-        child.logfile = sys.stdout
+        child = TestUtils.spawn(f'{CLI_NAME} config {Utils.get_first(browse)} --env {DEFAULT_ENV} '
+                              f'--skip-upgrade {self.extra_args}')
+        time.sleep(5) ## let browse start
 
         for i in range(0, self.key_down_to_shared):
             child.send(KEY_DOWN)
-            time.sleep(.02)
+            time.sleep(.25)
 
         child.send('e')
         child.send(KEY_DOWN)
@@ -70,14 +70,13 @@ class DevBrowse(FiggyTest):
 
         self.step("Get success. Deleting through browse.")
         # Delete Value
-        child = pexpect.spawn(f'{CLI_NAME} config {Utils.get_first(browse)} --env {DEFAULT_ENV} '
-                              f'--skip-upgrade {self.extra_args}',
-                              timeout=20, encoding='utf-8')
-        child.logfile = sys.stdout
+        child = TestUtils.spawn(f'{CLI_NAME} config {Utils.get_first(browse)} --env {DEFAULT_ENV} '
+                              f'--skip-upgrade {self.extra_args}')
+        time.sleep(5) ## let browse start
 
         for i in range(0, self.key_down_to_shared):
             child.send(KEY_DOWN)
-            time.sleep(.02)
+            time.sleep(.25)
 
         child.send('e')
         child.send(KEY_DOWN)
