@@ -1,14 +1,12 @@
-import sys
-
 import pexpect
+from figcli.test.cli.test_utils import TestUtils
+
+from figcli.test.cli.actions.delete import DeleteAction
+from figcli.test.cli.actions.get import GetAction
+from figcli.test.cli.actions.put import PutAction
 from figcli.test.cli.config import *
 from figcli.test.cli.figgy import FiggyTest
-from figcli.test.cli.dev.put import DevPut
-from figcli.test.cli.dev.get import DevGet
-from figcli.test.cli.dev.delete import DevDelete
-from figcli.config import *
 from figcli.utils.utils import *
-import time
 
 
 #Todo get this working...
@@ -23,15 +21,18 @@ class DevEdit(FiggyTest):
         self.step(f"Testing edit for {param_1}")
         self.edit()
 
+    def prep(self):
+        put = PutAction(extra_args=self.extra_args)
+        put.add(param_1, param_1_val, param_1_desc, delete_first=False)
+
     def edit(self):
         # Get Value
-        child = pexpect.spawn(f'{CLI_NAME} config {Utils.get_first(edit)} --env {DEFAULT_ENV} '
-                              f'--skip-upgrade {self.extra_args}',
-                              timeout=20, encoding='utf-8')
+        child = TestUtils.spawn(f'{CLI_NAME} config {Utils.get_first(edit)} --env {DEFAULT_ENV} '
+                              f'--skip-upgrade {self.extra_args}')
 
         child.expect('.*Please input a PS Name.*')
         child.sendline(param_1)
-        time.sleep(3) # Give edit time to start
+        time.sleep(12)  # Give edit time to start
         child.send(DevEdit._VALUE)
         child.sendcontrol('n')  # <-- sends TAB
         child.send(DevEdit._DESC)
@@ -39,9 +40,10 @@ class DevEdit(FiggyTest):
         child.sendcontrol('m')  # <-- Sends ENTER
         child.expect('.*secret.*')
         child.sendline('n')
+        child.expect('.*saved successfully.*')
         print("Add success. Checking successful save")
 
-        get = DevGet(extra_args=self.extra_args)
+        get = GetAction(extra_args=self.extra_args)
         get.get(param_1, DevEdit._VALUE, DevEdit._DESC)
-        delete = DevDelete(extra_args=self.extra_args)
+        delete = DeleteAction(extra_args=self.extra_args)
         delete.delete(param_1)
